@@ -18,9 +18,12 @@
 from firefox.webdriver import WebDriver as Firefox
 from firefox.firefox_profile import FirefoxProfile
 from chrome.webdriver import WebDriver as Chrome
+from chrome.options import Options as ChromeOptions
 from ie.webdriver import WebDriver as Ie
+from opera.webdriver import WebDriver as Opera
 from remote.webdriver import WebDriver as Remote
 from common.desired_capabilities import DesiredCapabilities
 from common.action_chains import ActionChains
+from common.proxy import Proxy
 
-__version__ = '2.16.0'
+__version__ = '2.17.0'
