@@ -21,6 +21,7 @@ import shutil
 import re
 import base64
 from cStringIO import StringIO
+from selenium.webdriver.common.proxy import Proxy
 
 WEBDRIVER_EXT = "webdriver.xpi"
 EXTENSION_NAME = "fxdriver@googlecode.com"
@@ -72,7 +73,9 @@ class FirefoxProfile(object):
         "security.warn_viewing_mixed.show_once": "false",
         "signon.rememberSignons": "false",
         "toolkit.networkmanager.disable": "true",
+        "toolkit.telemetry.enabled": "false",
         "toolkit.telemetry.prompted": "2",
+        "toolkit.telemetry.rejected": "true",
         "javascript.options.showInConsole": "true",
         "browser.dom.window.dump.enabled": "true",
         "webdriver_accept_untrusted_certs": "true",
@@ -115,6 +118,8 @@ class FirefoxProfile(object):
             clean_value = 'false'
         elif isinstance(value, str):
             clean_value = '"%s"' % value
+        elif isinstance(value, unicode):
+            clean_value = '"%s"' % value
         else:
             clean_value = str(int(value))
 
@@ -183,9 +188,34 @@ class FirefoxProfile(object):
         zipped.close()
         return base64.encodestring(fp.getvalue())
 
+    def set_proxy(self, proxy):
+        if proxy is None:
+            raise ValueError("proxy can not be None")
+
+        if proxy.proxy_type is Proxy.ProxyType.UNSPECIFIED:
+            return
+
+        self.set_preference("network.proxy.type", proxy.proxy_type)
+
+        if proxy.proxy_type is Proxy.ProxyType.MANUAL:
+            self.set_preference("network.proxy.no_proxies_on", proxy.no_proxy)
+            self._set_manual_proxy_preference("ftp", proxy.ftp_proxy)
+            self._set_manual_proxy_preference("http", proxy.http_proxy)
+            self._set_manual_proxy_preference("ssl", proxy.ssl_proxy)
+        elif proxy.proxy_type is Proxy.ProxyType.AUTODETECT:
+            self.set_preference("network.proxy.autoconfig_url", proxy.proxy_autoconfig_url)
 
     #Private Methods
 
+    def _set_manual_proxy_preference(self, key, setting):
+        if setting is None or setting is '':
+            return
+
+        host_details = setting.split(":")
+        self.set_preference("network.proxy.%s" % key, host_details[1][2:])
+        if len(host_details) > 1:
+            self.set_preference("network.proxy.%s_port" % key, int(host_details[2]))
+
     def _create_tempfolder(self):
         """
         Creates a temp folder to store User.js and the extension
